pub fn random_walkable_continuous_nearby<R: Rng>(
pos: (f64, f64),
radius: f64,
walkmap: &[bool],
grid_w: usize,
grid_h: usize,
extent_x: f64,
extent_y: f64,
periodic: bool,
rng: &mut R,
) -> Option<(f64, f64)>Expand description
Returns a random walkable continuous position within Euclidean radius
r of pos.
Finds walkable grid cells near pos, picks one randomly, then returns
a random continuous position within that cell that is within r of pos.
Returns None if no walkable cells exist nearby.